#ifndef SO_SCREEN_POSITIONER_H
#define SO_SCREEN_POSITIONER_H
/*****************************************************************************\
 *
 * SoScreenPositioner.h
 *
 * Screen positioning node.
 * Acts as special camera and sets the orthographic projection 
 * in a special way convenient for menus and other stuff.
 * One common use is for the graphic items that shall stay 
 * on their places independently on the window size.
 *
 * Authors: PCJohn (peciva _at fit.vutbr.cz)
 * Contributors:
 *
 * ----------------------------------------------------------------------------
 *
 * THIS SOFTWARE IS NOT COPYRIGHTED
 *
 * This source code is offered for use in the public domain.
 * You may use, modify or distribute it freely.
 *
 * This source code is distributed in the hope that it will be useful but
 * WITHOUT ANY WARRANTY.  ALL WARRANTIES, EXPRESS OR IMPLIED ARE HEREBY
 * DISCLAIMED.  This includes but is not limited to warranties of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * If you find the source code useful, authors will kindly welcome
 * if you give them credit and keep their names with their source code,
 * but do not feel forced to do so.
 *
\*****************************************************************************/


#include <Inventor/nodes/SoOrthographicCamera.h>
#include <Inventor/fields/SoSFFloat.h>
#include <Inventor/fields/SoSFVec2f.h>
#include <Inventor/fields/SoSFVec2s.h>



class SoScreenPositioner : public SoOrthographicCamera {
  typedef SoOrthographicCamera inherited;

  SO_NODE_HEADER(SoScreenPositioner);

public:

  SoSFVec2f screenOrigin;
  SoSFVec2s screenPosition;

  SoSFFloat pixelsPerUnit;
  SoSFFloat unitsPerScreen;


  SoScreenPositioner();

  static void initClass();
  static void cleanup();

  virtual void doAction(SoAction * action);
  virtual void callback(SoCallbackAction * action);
  virtual void GLRender(SoGLRenderAction * action);
  virtual void getBoundingBox(SoGetBoundingBoxAction * action);
  virtual void getMatrix(SoGetMatrixAction * action);
  virtual void handleEvent(SoHandleEventAction * action);
  virtual void pick(SoPickAction * action);
  virtual void getPrimitiveCount(SoGetPrimitiveCountAction * action);
  virtual void audioRender(SoAudioRenderAction * action);
  virtual SbViewVolume getViewVolume(float useaspectratio) const;

protected:
  class SoScreenPositionerP *pimpl;
  virtual ~SoScreenPositioner();
};


#endif /* SO_SCREEN_POSITIONER_H */
